
### <a name="manual"></a> Text block

Insert standard paragraph.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----------|
| type      |  text                 |
| content   |  Paragraph            |
| style     |  (optional) style name from user defined styles  | BodyText |
| vertical  |  (optional) renders text vertically  | False |

Example:
```YAML
- type    : text
  content : >
    Some text...
```

Back to [Documentation](../../../README.md#block_basic)
